@@ -8,6 +8,7 @@ use either::Either;
 use log::trace;
 use num_bigint::BigInt as BigIntValue;
 use std::fmt::Write;
+use swc_common::SyntaxContext;
 
 impl<'a, I: Input> Lexer<'a, I> {
     /// Reads an integer, octal integer, or floating-point number
@@ -188,7 +189,7 @@ impl<'a, I: Input> Lexer<'a, I> {
             radix,
             |total, radix, v| {
                 read_any = true;
-                (f64::mul_add(total, radix as f64, v as f64), true)
+                Ok((f64::mul_add(total, radix as f64, v as f64), true))
             },
             &mut Raw(None),
             true,
@@ -227,7 +228,7 @@ impl<'a, I: Input> Lexer<'a, I> {
                     non_octal = true;
                 }
 
-                (f64::mul_add(total, radix as f64, v as f64), true)
+                Ok((f64::mul_add(total, radix as f64, v as f64), true))
             },
             &mut raw,
             true,
@@ -269,7 +270,8 @@ impl<'a, I: Input> Lexer<'a, I> {
             |opt: Option<f64>, radix, val| {
                 count += 1;
                 let total = opt.unwrap_or_default() * radix as f64 + val as f64;
-                (Some(total), count != len as u16)
+
+                Ok((Some(total), count != len as u16))
             },
             raw,
             true,
@@ -287,13 +289,26 @@ impl<'a, I: Input> Lexer<'a, I> {
         len: u8,
         raw: &mut Raw,
     ) -> LexResult<Option<u32>> {
+        let start = self.state.start;
+
         let mut count = 0;
         let v = self.read_digits(
             radix,
             |opt: Option<u32>, radix, val| {
                 count += 1;
-                let total = opt.unwrap_or_default() * radix as u32 + val as u32;
-                (Some(total), count != len)
+
+                let total = opt
+                    .unwrap_or_default()
+                    .checked_mul(radix as u32)
+                    .and_then(|v| v.checked_add(val as u32))
+                    .ok_or_else(|| {
+                        let span = Span::new(start, start, SyntaxContext::empty());
+                        Error {
+                            error: Box::new((span, SyntaxError::InvalidUnicodeEscape)),
+                        }
+                    })?;
+
+                Ok((Some(total), count != len))
             },
             raw,
             true,
@@ -314,7 +329,7 @@ impl<'a, I: Input> Lexer<'a, I> {
         allow_num_separator: bool,
     ) -> LexResult<Ret>
     where
-        F: FnMut(Ret, u8, u32) -> (Ret, bool),
+        F: FnMut(Ret, u8, u32) -> LexResult<(Ret, bool)>,
         Ret: Copy + Default,
     {
         debug_assert!(
@@ -385,7 +400,7 @@ impl<'a, I: Input> Lexer<'a, I> {
             raw.push(c);
 
             self.bump();
-            let (t, cont) = op(total, radix, val);
+            let (t, cont) = op(total, radix, val)?;
             total = t;
             if !cont {
                 return Ok(total);
